@@ -141,9 +141,13 @@ abstract class XmlaOlap4jConnection implements OlapConnection {
     /**
      * This is a private property used for development only.
      * Enabling it makes the connection print out all queries
-     * to {@link System#out}
+     * to {@link System#out}.
+     *
+     * <p>To enable externally, set the environment variable:
+     * <code>olap4j.xmla.debug=true</code>.
      */
-    private static final boolean DEBUG = false;
+    private static final boolean DEBUG =
+        Boolean.valueOf(System.getProperty("olap4j.xmla.debug"));
 
     /**
      * Creates an Olap4j connection an XML/A provider.
@@ -347,30 +351,54 @@ abstract class XmlaOlap4jConnection implements OlapConnection {
         }
         StringBuilder buf = new StringBuilder();
         for (String prop : databaseProperties.keySet()) {
-            if (prop.startsWith(
-                    XmlaOlap4jDriver.Property.CACHE.name()))
-            {
+            if (prop.startsWith(XmlaOlap4jDriver.Property.CACHE.name())) {
                 // Skip over the pass-through properties for the cache.
                 continue;
             }
             try {
-                XmlaOlap4jDriver.Property.valueOf(prop);
-                continue;
-            } catch (IllegalArgumentException e) {
-                if (olap4jDatabaseProperties.contains(prop)) {
-                    buf.append("        <");
-                    xmlEncode(buf, prop);
-                    buf.append(">");
-                    xmlEncode(buf, databaseProperties.get(prop));
-                    buf.append("</");
-                    xmlEncode(buf, prop);
-                    buf.append(">\n");
+                final XmlaOlap4jDriver.Property property =
+                    XmlaOlap4jDriver.Property.valueOf(prop);
+                switch (property) {
+                case CATALOG:
+                    // Before we've connected, there's no way to tell
+                    // whether we're talking to Essbase.
+                    if (olap4jDatabase != null) {
+                        // Use the special version of getFlavor here
+                        // because there isn't a connection extablished yet.
+                        switch (getFlavor(false)) {
+                        case ESSBASE:
+                            // Essbase needs a CATALOG property.
+                            outputProp(buf, prop);
+                            break;
+                        default:
+                            // Just making the compiler happy.
+                            break;
+                        }
+                    }
+                    break;
+                default:
+                    // Just making the compiler happy.
+                    break;
                 }
+            } catch (IllegalArgumentException e) {
+                outputProp(buf, prop);
             }
         }
         return buf.toString();
     }
 
+    private void outputProp(StringBuilder buf, String prop) {
+        if (olap4jDatabaseProperties.contains(prop)) {
+            buf.append("        <");
+            xmlEncode(buf, prop);
+            buf.append(">");
+            xmlEncode(buf, databaseProperties.get(prop));
+            buf.append("</");
+            xmlEncode(buf, prop);
+            buf.append(">\n");
+        }
+    }
+
     public OlapStatement createStatement() {
         return factory.newStatement(this);
     }
@@ -763,7 +791,8 @@ abstract class XmlaOlap4jConnection implements OlapConnection {
      * Clears the cache.
      */
     private void clearCache() {
-        ((DeferredNamedListImpl) this.olapDatabases).reset();
+        ((DeferredNamedListImpl<XmlaOlap4jDatabase>)this.olapDatabases)
+            .reset();
         this.olap4jCatalog = null;
         this.olap4jDatabase = null;
         this.olap4jSchema = null;
@@ -806,12 +835,25 @@ abstract class XmlaOlap4jConnection implements OlapConnection {
         throw new UnsupportedOperationException();
     }
 
+    /**
+     * This is a special rewrite of
+     * {@link BackendFlavor#getFlavor(OlapConnection, boolean)} to get the
+     * backend flavor without having to actually connect. It should not be used
+     * outside of the connection's constructor.
+     */
+    protected BackendFlavor getFlavor(boolean fail) throws OlapException {
+        final Database database = getOlapDatabase();
+        final String dataSourceInfo = database.getDataSourceInfo();
+        final String provider = database.getProviderName();
+        return BackendFlavor.getFlavor(dataSourceInfo, provider, fail);
+    }
+
     /**
      * Enumeration of server backends. Use
      * {@link BackendFlavor#getFlavor(XmlaOlap4jConnection)}
      * to get the vendor for a given connection.
      */
-    static enum BackendFlavor {
+    enum BackendFlavor {
         MONDRIAN("Mondrian"),
         SSAS("Microsoft"),
         PALO("Palo"),
@@ -825,17 +867,32 @@ abstract class XmlaOlap4jConnection implements OlapConnection {
             this.token = token;
         }
 
-        static BackendFlavor getFlavor(XmlaOlap4jConnection conn)
+        static BackendFlavor getFlavor(OlapConnection conn, boolean fail)
             throws OlapException
         {
-            final String dataSourceInfo =
-                conn.getOlapDatabase().getDataSourceInfo();
+            return getFlavor(
+                conn.getOlapDatabase().getDataSourceInfo(),
+                conn.getOlapDatabase().getProviderName(),
+                fail);
+        }
+
+        static BackendFlavor getFlavor(
+            String dataSourceInfo, String providerName, boolean fail)
+        {
             for (BackendFlavor flavor : BackendFlavor.values()) {
-                if (dataSourceInfo.contains(flavor.token)) {
+                if (providerName.toUpperCase()
+                        .contains(flavor.token.toUpperCase())
+                    || dataSourceInfo.toUpperCase()
+                        .contains(flavor.token.toUpperCase()))
+                {
                     return flavor;
                 }
             }
-            throw new AssertionError("Can't determine the backend vendor.");
+            if (fail) {
+                throw new AssertionError("Can't determine the backend vendor.");
+            } else {
+                return UNKNOWN;
+            }
         }
     }
 
@@ -1048,7 +1105,9 @@ abstract class XmlaOlap4jConnection implements OlapConnection {
         // Add the datasource node only if this request requires it.
         if (metadataRequest.requiresDatasourceName()) {
             final String dataSourceInfo;
-            switch (BackendFlavor.getFlavor(context.olap4jConnection)) {
+            // Use the call to getFlavor here instead of going through
+            // BackendFlavor or risk going into a loop.
+            switch (context.olap4jConnection.getFlavor(true)) {
             case ESSBASE:
                 dataSourceInfo =
                     context.olap4jConnection.getOlapDatabase()
@@ -1421,12 +1480,16 @@ abstract class XmlaOlap4jConnection implements OlapConnection {
                 stringElement(row, "ALL_MEMBER");
             final String defaultMemberUniqueName =
                 stringElement(row, "DEFAULT_MEMBER");
+            final String hierarchyDisplayFolder =
+                stringElement(row, "HIERARCHY_DISPLAY_FOLDER");
+
             XmlaOlap4jHierarchy hierarchy = new XmlaOlap4jHierarchy(
                 context.getDimension(row),
                 hierarchyUniqueName,
                 hierarchyName,
                 hierarchyCaption,
                 description,
+                hierarchyDisplayFolder,
                 allMember != null,
                 defaultMemberUniqueName);
             list.add(hierarchy);
@@ -1487,8 +1550,11 @@ abstract class XmlaOlap4jConnection implements OlapConnection {
             final int levelNumber =
                 integerElement(row, "LEVEL_NUMBER");
             final Integer levelTypeCode = integerElement(row, "LEVEL_TYPE");
-            final Level.Type levelType =
+            Level.Type optionalLevelType =
                 Level.Type.getDictionary().forOrdinal(levelTypeCode);
+            final Level.Type levelType =
+                optionalLevelType == null ? Level.Type.REGULAR
+                    : optionalLevelType;
             boolean calculated = (levelTypeCode & MDLEVEL_TYPE_CALCULATED) != 0;
             final int levelCardinality =
                 integerElement(row, "LEVEL_CARDINALITY");
@@ -1535,6 +1601,8 @@ abstract class XmlaOlap4jConnection implements OlapConnection {
                 stringElement(row, "DESCRIPTION");
             final String formatString =
                 stringElement(row, "DEFAULT_FORMAT_STRING");
+            final String measureDisplayFolder =
+                stringElement(row, "MEASURE_DISPLAY_FOLDER");
             final Measure.Aggregator measureAggregator =
                 Measure.Aggregator.getDictionary().forOrdinal(
                     integerElement(
@@ -1567,6 +1635,7 @@ abstract class XmlaOlap4jConnection implements OlapConnection {
                 new XmlaOlap4jMeasure(
                     (XmlaOlap4jLevel)member.getLevel(), measureUniqueName,
                     measureName, measureCaption, description, formatString,
+                    measureDisplayFolder,
                     null, measureAggregator, datatype, measureIsVisible,
                     member.getOrdinal()));
         }
