@@ -18,6 +18,7 @@
 package org.olap4j.driver.xmla;
 
 import org.olap4j.OlapException;
+import org.olap4j.driver.xmla.XmlaOlap4jConnection.BackendFlavor;
 import org.olap4j.impl.*;
 import org.olap4j.mdx.IdentifierSegment;
 import org.olap4j.metadata.*;
@@ -453,8 +454,8 @@ class XmlaOlap4jCube implements Cube, Named
                 }
                 throw new IllegalArgumentException(
                     "more than one member with unique name '"
-                        + memberUniqueName
-                        + "'");
+                    + memberUniqueName
+                    + "'");
             }
         }
 
@@ -462,12 +463,13 @@ class XmlaOlap4jCube implements Cube, Named
             List<String> memberUniqueNames,
             Map<String, XmlaOlap4jMember> memberMap) throws OlapException
         {
-            if (olap4jSchema.olap4jCatalog.olap4jDatabaseMetaData
-                    .olap4jConnection.getDatabase()
-                    .indexOf("Provider=Mondrian") != -1)
-            {
+            final XmlaOlap4jDatabaseMetaData m =
+                olap4jSchema.olap4jCatalog.olap4jDatabaseMetaData;
+            switch (BackendFlavor.getFlavor(m.olap4jConnection, false)) {
+            case MONDRIAN:
                 mondrianMembersLookup(memberUniqueNames, memberMap);
-            } else {
+                break;
+            default:
                 genericMembersLookup(memberUniqueNames, memberMap);
             }
         }
