@@ -31,7 +31,12 @@ abstract class Olap4jNodeConverter {
 
     public static SelectNode toOlap4j(Query query) {
         List<IdentifierNode> list = Collections.emptyList();
-        List<ParseTreeNode> withList = Collections.emptyList();
+        List<ParseTreeNode> withList;
+        if (query.getWithList().isEmpty()) {
+            withList = Collections.emptyList();
+        } else {
+            withList = query.getWithList();
+        }
         List<QueryAxis> axisList = new ArrayList<QueryAxis>();
         axisList.add(query.getAxes().get(Axis.COLUMNS));
         axisList.add(query.getAxes().get(Axis.ROWS));
@@ -293,7 +298,14 @@ abstract class Olap4jNodeConverter {
                 axis, 0, null, unions, selsWithContext, contextUnions);
             unions.addAll(contextUnions);
             if (unions.size() > 1) {
-                callNode = generateHierarchizeUnion(unions);
+                if (axis.getHierarchizeMode() != null
+                    && axis.getHierarchizeMode()
+                        .equals(QueryDimension.HierarchizeMode.POST))
+                {
+                    callNode = generateHierarchizeUnionPost(unions);
+                } else {
+                    callNode = generateHierarchizeUnion(unions);
+                }
             } else {
                 callNode = generateCrossJoin(unions.get(0));
             }
@@ -301,53 +313,53 @@ abstract class Olap4jNodeConverter {
 
         ParseTreeNode filteredNode = null;
         if (axis.getFilterCondition() != null) {
-        	LiteralNode conditionNode = 
-        		LiteralNode.createSymbol(
-                        null,
-                        axis.getFilterCondition());
-        	filteredNode =
-    	    	    new CallNode(
-    	    	    	    null,
-    	    	    	    "Filter",
-    	    	    	    Syntax.Function,
-    	    	    	    callNode,
-    	    	    	    conditionNode);
+            LiteralNode conditionNode =
+                LiteralNode.createSymbol(
+                    null,
+                    axis.getFilterCondition());
+            filteredNode =
+                new CallNode(
+                    null,
+                    "Filter",
+                    Syntax.Function,
+                    callNode,
+                    conditionNode);
         } else {
-        	filteredNode = callNode;
+            filteredNode = callNode;
         }
         // We might need to limit the axis set
         ParseTreeNode limitedNode = null;
         if (axis.getLimitFunction() != null) {
-        	ParseTreeNode n =
-        	    LiteralNode.createNumeric(
-        	            null, 
-        	            axis.getLimitFunctionN(), 
-        	            false);
-        	if (axis.getLimitFunctionSortLiteral() != null) {
-            	LiteralNode evaluatorNode = null;
-        		evaluatorNode = 
-        		    LiteralNode.createSymbol(
+            ParseTreeNode n =
+                LiteralNode.createNumeric(
+                    null,
+                    axis.getLimitFunctionN(),
+                    false);
+            if (axis.getLimitFunctionSortLiteral() != null) {
+                LiteralNode evaluatorNode = null;
+                evaluatorNode =
+                    LiteralNode.createSymbol(
                         null,
                         axis.getLimitFunctionSortLiteral());
-        	    limitedNode =
-        	    	    new CallNode(
-        	    	    	    null,
-        	    	    	    axis.getLimitFunction().toString(),
-        	    	    	    Syntax.Function,
-        	    	    	    filteredNode,
-        	    	    	    n,
-        	    	    	    evaluatorNode);
-        	} else {
-        		limitedNode =
-        	    	    new CallNode(
-        	    	    	    null,
-        	    	    	    axis.getLimitFunction().toString(),
-        	    	    	    Syntax.Function,
-        	    	    	    filteredNode,
-        	    	    	    n);
-        	}
+                limitedNode =
+                    new CallNode(
+                        null,
+                        axis.getLimitFunction().toString(),
+                        Syntax.Function,
+                        filteredNode,
+                        n,
+                        evaluatorNode);
+            } else {
+                limitedNode =
+                    new CallNode(
+                        null,
+                        axis.getLimitFunction().toString(),
+                        Syntax.Function,
+                        filteredNode,
+                        n);
+            }
         } else {
-        	limitedNode = filteredNode;
+            limitedNode = filteredNode;
         }
         // We might need to sort the whole axis.
         ParseTreeNode sortedNode = null;
@@ -377,6 +389,16 @@ abstract class Olap4jNodeConverter {
             sortedNode);
     }
 
+    protected static CallNode generateHierarchizeUnionPost(
+        List<List<ParseTreeNode>> unions)
+    {
+        return new CallNode(
+            null, "Hierarchize", Syntax.Function,
+            generateUnion(unions),
+            LiteralNode.createSymbol(
+                null, QueryDimension.HierarchizeMode.POST.name()));
+    }
+
     private static List<ParseTreeNode> toOlap4j(QueryDimension dimension) {
         // Let's build a first list of included members.
         List<ParseTreeNode> includeList = new ArrayList<ParseTreeNode>();
